@@ -13,6 +13,8 @@
 
 using std::ofstream;
 using settings::getSetting;
+using settings::ps2tex;
+using settings::tex2ps;
 using vm::array;
 using vm::read;
 
@@ -63,7 +65,7 @@ void texfile::prologue()
   if(inlinetex) {
     string prename=buildname(settings::outname(),"pre");
     std::ofstream *outpreamble=new std::ofstream(prename.c_str());
-    texpreamble(*outpreamble,processData().TeXpreamble);
+    texpreamble(*outpreamble,processData().TeXpreamble,true,false);
     outpreamble->close();
   }
   
@@ -98,7 +100,7 @@ void texfile::prologue()
     }
   }
   
-  if(settings::xe(texengine))
+  if(settings::xe(texengine) && !inlinetex)
     *out << "\\usepackage{everypage}%" << newl;
   
   if(settings::latex(texengine)) {
@@ -136,14 +138,6 @@ void texfile::prologue()
     }
   }
   
-// Workaround Adobe Reader transparency artifact:
-  if(settings::pdf(texengine)) {
-    if(settings::xe(texengine))
-      *out << "\\AddEverypageHook{\\special{pdf: put @thispage <</Group << /S /Transparency /I true /CS /DeviceRGB>> >>}}%" << newl;
-    else
-      *out << "\\pdfpageattr{/Group <</S /Transparency /I true /CS /DeviceRGB>>}%" << newl;
-  }
-  
   beginpage();
 }
     
@@ -157,24 +151,18 @@ void texfile::beginlayer(const string& psname, bool postscript)
         *out << "{\\catcode`\"=12%" << newl
              << "\\includegraphics";
         bool pdf=settings::pdf(texengine);
-        string quote;
         string name=stripExt(psname);
         if(inlinetex) {
           size_t pos=name.rfind("-");
           if(pos < string::npos) name="\\ASYprefix\\jobname"+name.substr(pos);
         } else {
-          name=pdf ? stripExt(psname) : psname;
-          if(stripDir(name) != name)
-            quote="\"";
+          if(!pdf) name=psname;
         }
         
-        if(pdf) *out << "{" << quote << name << quote << ".pdf}%" << newl;
-        else {
+        if(!pdf)
           *out << "[bb=" << box.left << " " << box.bottom << " "
-               << box.right << " " << box.top << "]"
-               << "{" << quote << name << quote << "}%" << newl;
-        }
-        *out << "}%" << newl;
+               << box.right << " " << box.top << "]";
+        *out << "{" << name << "}%" << newl << "}%" << newl;
       }
       if(!inlinetex)
         *out << "\\kern " << (box.left-box.right)*ps2tex << "pt%" << newl;
@@ -357,10 +345,11 @@ void svgtexfile::endspecial()
   
 void svgtexfile::begintransform()
 {
-  *out << "<g transform='matrix(1 0 0 1 "
-       << (-Hoffset+1.99*settings::cm)*ps2tex << " " 
-       << (1.9*settings::cm+box.top)*ps2tex 
-       << ")'>" << nl;
+  bbox b=box;
+  b.left=-Hoffset;
+  b=svgbbox(b);
+  *out << "<g transform='matrix(" << tex2ps << " 0 0 " << tex2ps <<" "
+       << b.left << " " << b.top << ")'>" << nl;
 }
     
 void svgtexfile::endtransform()
